<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="86"/>
        <location filename="../main.cpp" line="118"/>
        <source>Deepin Movie</source>
        <translation>Видеопроигрыватель Deepin </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="87"/>
        <source>Deepin Movie is a well-designed and full-featured video player with simple borderless design. It supports local and streaming media play with multiple video formats.</source>
        <translation>Видеопроигрыватель Deepin  - это полнофункциональный и хорошо продуманный видео-плеер с невероятно простым дизайном. Он поддерживает локальное и потоковое воспроизведение многих видео форматов.</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="116"/>
        <source>Invalid folder</source>
        <translation>Неверная папка</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="130"/>
        <source>Open Folder</source>
        <translation>Открыть Папку</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="121"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>У вас нет разрешения на использование этой папки</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="5"/>
        <source>Auto add similar files to play</source>
        <translation>Автоматически  добавить похожие файлы для воспроизведения</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="6"/>
        <source>Clear playlist when exit</source>
        <translation>Очистить плейлист при выходе</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="7"/>
        <source>Show video preview on mouseover</source>
        <translation>Показать предварительный просмотр видео с помощью мыши</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="8"/>
        <source>Open a new player for each file played</source>
        <translation>Открывать новый плеер для каждого воспроизводимого файла</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="9"/>
        <source>Pause when minimized</source>
        <translation>Пауза при сворачивании</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="10"/>
        <source>Remember playback position</source>
        <translation>Запомнить воспроизводимую позицию</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="11"/>
        <source>Path</source>
        <translation>Путь</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="12"/>
        <source>Basic</source>
        <translation>Основной</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="13"/>
        <source>Play</source>
        <translation>Воспроизведение</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="14"/>
        <location filename="../common/settings_translation.cpp" line="19"/>
        <source>Screenshot</source>
        <translation>Скриншот</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="15"/>
        <source>Shortcuts</source>
        <translation>Сочетание клавиш</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="16"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="17"/>
        <source>Frame/Sound</source>
        <translation>Кадр/Звук</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="18"/>
        <source>Playback</source>
        <translation>Воспроизведение</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="20"/>
        <location filename="../common/settings_translation.cpp" line="21"/>
        <source>Subtitle</source>
        <translation>Субтитры</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="22"/>
        <source>Font Style</source>
        <translation>Стиль Шрифта</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="23"/>
        <source>Restore Defaults</source>
        <translation>Восстановить Значения по умолчанию</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="24"/>
        <source>Open file</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="25"/>
        <source>Open next</source>
        <translation>Открыть следующий</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="26"/>
        <source>Open previous</source>
        <translation>Открыть предыдущий</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="27"/>
        <source>Mini mode</source>
        <translation>Компактный вид</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="28"/>
        <source>Mute</source>
        <translation>Приглушить</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="29"/>
        <source>volume down</source>
        <translation>тише</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="30"/>
        <source>Volume up</source>
        <translation>Громче</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="31"/>
        <source>Speed up</source>
        <translation>Ускорить</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="32"/>
        <source>Speed down</source>
        <translation>Замедлить</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="33"/>
        <source>Fullscreen</source>
        <translation>Полноэкранный режим</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="34"/>
        <source>Pause/Play</source>
        <translation>Пауза/Воспроизведение</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="35"/>
        <source>Playlist</source>
        <translation>Список воспроизведения</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="36"/>
        <source>Reset speed</source>
        <translation>Сбросить скорость</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="37"/>
        <source>Rewind</source>
        <translation>Перемотка назад</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="38"/>
        <source>Forward</source>
        <translation>Перемотка вперед</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="39"/>
        <source>Burst screenshot</source>
        <translation>Серия скриншотов</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="40"/>
        <source>Film screenshot</source>
        <translation>Скриншот фильма</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="41"/>
        <source>0.5s backward</source>
        <translation>Перемотка назад 0.5с</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="42"/>
        <source>0.5s forward</source>
        <translation>Перемотка вперед 0.5с</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="43"/>
        <source>Font</source>
        <translation>Шрифт</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="44"/>
        <source>Font Size</source>
        <translation>Размер Шрифта</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="41"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="42"/>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="46"/>
        <source>Please enter the URL:</source>
        <translation>Пожалуйста, введите адрес в интернете:</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <location filename="../common/actions.cpp" line="82"/>
        <location filename="../common/actions.cpp" line="102"/>
        <source>Open File</source>
        <translation>Открыть Файл</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="84"/>
        <location filename="../common/actions.cpp" line="265"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="85"/>
        <source>Light Theme</source>
        <translation>Светлая Тема</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="108"/>
        <source>Fullscreen</source>
        <translation>Полноэкранный режим</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="110"/>
        <source>Always on Top</source>
        <translation>Всегда Поверх Окон</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="280"/>
        <source>Film info</source>
        <translation>Информация о фильме</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="83"/>
        <location filename="../common/actions.cpp" line="103"/>
        <source>Open Folder</source>
        <translation>Открыть Папку</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="104"/>
        <source>Open URL</source>
        <translation>Открыть URL</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="105"/>
        <source>Open CD/DVD</source>
        <translation>Открыть CD/DVD</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="109"/>
        <source>Mini Mode</source>
        <translation>Компактный Вид</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="115"/>
        <source>Play Mode</source>
        <translation>Режим Воспроизведения</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="118"/>
        <source>Order Play</source>
        <translation>Порядок Проигрывания</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="119"/>
        <source>Shuffle Play</source>
        <translation>Перемешать</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="120"/>
        <source>Single Play</source>
        <translation>Одиночный</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="121"/>
        <source>Single Loop</source>
        <translation>Одиночный Цикл</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="122"/>
        <source>List Loop</source>
        <translation>Непрерывно</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="129"/>
        <source>Frame</source>
        <translation>Кадр</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="132"/>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="140"/>
        <source>Clockwise</source>
        <translation>По часовой стрелке</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="141"/>
        <source>Counterclockwise</source>
        <translation>Против часовой стрелки</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="148"/>
        <source>Sound</source>
        <translation>Звук</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="151"/>
        <source>Channel</source>
        <translation>Канал</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="154"/>
        <source>Stereo</source>
        <translation>Стерео</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="155"/>
        <source>Left channel</source>
        <translation>Левый канал</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="156"/>
        <source>Right channel</source>
        <translation>Правый канал</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="162"/>
        <source>Track</source>
        <translation>Дорожка</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="172"/>
        <source>Subtitle</source>
        <translation>Субтитры</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="173"/>
        <source>Load</source>
        <translation>Загрузка</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="174"/>
        <source>Online Search</source>
        <translation>Поиск Онлайн</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="178"/>
        <source>Select</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="182"/>
        <source>Hide</source>
        <translation>Скрыть</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="186"/>
        <source>Encodings</source>
        <translation>Кодировка</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="254"/>
        <source>Screenshot</source>
        <translation>Скриншот</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="255"/>
        <source>Film Screenshot</source>
        <translation>Скриншот Фильма</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="256"/>
        <source>Burst Shooting</source>
        <translation>Серия Снимков</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="263"/>
        <source>Playlist</source>
        <translation>Список воспроизведения</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="264"/>
        <source>Film Info</source>
        <translation>Информация о Фильме</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="278"/>
        <source>Clear playlist</source>
        <translation>Очистить список воспроизведения</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="279"/>
        <source>Display in file manager</source>
        <translation>Отобразить в менеджере файлов</translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="88"/>
        <source>duration: %1</source>
        <translation>продолжительность: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="94"/>
        <source>resolution: %1</source>
        <translation>разрешение: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="100"/>
        <source>size: %1</source>
        <translation>размер: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="123"/>
        <source>save</source>
        <translation>сохранить</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <location filename="../common/mainwindow.cpp" line="785"/>
        <location filename="../common/mainwindow.cpp" line="2279"/>
        <location filename="../common/mainwindow.cpp" line="2374"/>
        <source>Deepin Movie</source>
        <translation>Видеопроигрыватель Deepin </translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="698"/>
        <location filename="../common/mainwindow.cpp" line="1796"/>
        <source>Load successfully</source>
        <translation>Загрузка успешно завершена</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="698"/>
        <location filename="../common/mainwindow.cpp" line="1796"/>
        <source>Load failed</source>
        <translation>Ошибка загрузки</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1402"/>
        <source>No device found</source>
        <translation>Устройство не найдено</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1420"/>
        <source>Parse Failed</source>
        <translation>Ошибка Анализа</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1427"/>
        <source>Open Folder</source>
        <translation>Открыть Папку</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1442"/>
        <location filename="../common/mainwindow.cpp" line="1459"/>
        <location filename="../common/mainwindow.cpp" line="1791"/>
        <source>Open File</source>
        <translation>Открыть Файл</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1444"/>
        <location filename="../common/mainwindow.cpp" line="1461"/>
        <source>All videos (%1)</source>
        <translation>Все видео (%1)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1659"/>
        <source>Muted</source>
        <translation>Заглушенный</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1662"/>
        <location filename="../common/mainwindow.cpp" line="1674"/>
        <location filename="../common/mainwindow.cpp" line="1684"/>
        <location filename="../common/mainwindow.cpp" line="1691"/>
        <source>Volume: %1%</source>
        <translation>Громкость:  %1%</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1756"/>
        <location filename="../common/mainwindow.cpp" line="1764"/>
        <source>Subtitle %1: %2s</source>
        <translation>Субтитры: %1: %2s</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1757"/>
        <location filename="../common/mainwindow.cpp" line="1765"/>
        <source>delayed</source>
        <translation>задержка</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1757"/>
        <location filename="../common/mainwindow.cpp" line="1765"/>
        <source>advanced</source>
        <translation>расширенный</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1772"/>
        <location filename="../common/mainwindow.cpp" line="1779"/>
        <location filename="../common/mainwindow.cpp" line="1786"/>
        <source>Speed: %1x</source>
        <translation>Скорость: %1x</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1793"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)</source>
        <translation>Субтитры (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1855"/>
        <source>View</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1866"/>
        <source>Movie Screenshot</source>
        <translation>Скриншот Фильма</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1867"/>
        <source>Saved to</source>
        <translation>Сохранить в</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1881"/>
        <location filename="../common/mainwindow.cpp" line="1952"/>
        <source>The screenshot is saved</source>
        <translation>Снимок экрана сохранен</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1881"/>
        <source>The screenshot is failed to save</source>
        <translation>Снимок экрана сохранить не удалось</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="2039"/>
        <location filename="../common/mainwindow.cpp" line="2728"/>
        <source>Invalid file: %1</source>
        <translation>Неверный файл: %1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="118"/>
        <source>File Type:</source>
        <translation>Тип Файла:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="119"/>
        <source>Resolution:</source>
        <translation>Разрешение:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="120"/>
        <source>File Size:</source>
        <translation>Размер Файла:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="121"/>
        <source>Duration:</source>
        <translation>Продолжительность:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="126"/>
        <source>File Path:</source>
        <translation>Путь к Файлу:</translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1017"/>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1035"/>
        <source>[internal]</source>
        <translation>[внутренний]</translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <location filename="../widgets/playlist_widget.cpp" line="192"/>
        <location filename="../widgets/playlist_widget.cpp" line="227"/>
        <location filename="../widgets/playlist_widget.cpp" line="402"/>
        <source>File does not exist</source>
        <translation>Файл отсутствует</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <location filename="../common/dmr_settings.cpp" line="155"/>
        <source>%1/DMovie%2.jpg</source>
        <translation>%1/DMovie%2.jpg</translation>
    </message>
    <message>
        <location filename="../common/dmr_settings.cpp" line="161"/>
        <source>%1/DMovie%2(%3).jpg</source>
        <translation>%1/DMovie%2(%3).jpg</translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="889"/>
        <source>Play</source>
        <translation>Воспроизведение</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="685"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Previous</source>
        <translation>Предыдущий</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="686"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Next</source>
        <translation>Следующий</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="687"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Subtitles</source>
        <translation>Субтитры</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="688"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Playlist</source>
        <translation>Список воспроизведения</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="689"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="876"/>
        <source>Fullscreen</source>
        <translation>Полноэкранный режим</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="683"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Play/Pause</source>
        <translation>Воспроизведение / Пауза</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="873"/>
        <source>Exit fullscreen</source>
        <translation>Выйти из полноэкранного режима</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="886"/>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
</context>
</TS>